@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.binaryauthorization_v1.services.binauthz_management_service_v1 import (
     pagers,
 )
@@ -124,6 +129,42 @@ class BinauthzManagementServiceV1AsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return BinauthzManagementServiceV1Client.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> BinauthzManagementServiceV1Transport:
         """Returns the transport used by the client instance.
@@ -187,10 +228,10 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def get_policy(
         self,
-        request: service.GetPolicyRequest = None,
+        request: Union[service.GetPolicyRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
@@ -207,7 +248,7 @@ class BinauthzManagementServiceV1AsyncClient:
         project does not have one.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.GetPolicyRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.GetPolicyRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.GetPolicy][].
             name (:class:`str`):
@@ -279,10 +320,10 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def update_policy(
         self,
-        request: service.UpdatePolicyRequest = None,
+        request: Union[service.UpdatePolicyRequest, dict] = None,
         *,
         policy: resources.Policy = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
@@ -296,7 +337,7 @@ class BinauthzManagementServiceV1AsyncClient:
         request is malformed.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.UpdatePolicyRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.UpdatePolicyRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdatePolicy][].
             policy (:class:`google.cloud.binaryauthorization_v1.types.Policy`):
@@ -373,12 +414,12 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def create_attestor(
         self,
-        request: service.CreateAttestorRequest = None,
+        request: Union[service.CreateAttestorRequest, dict] = None,
         *,
         parent: str = None,
         attestor_id: str = None,
         attestor: resources.Attestor = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -392,7 +433,7 @@ class BinauthzManagementServiceV1AsyncClient:
         already exists.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.CreateAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.CreateAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.CreateAttestor][].
             parent (:class:`str`):
@@ -477,10 +518,10 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def get_attestor(
         self,
-        request: service.GetAttestorRequest = None,
+        request: Union[service.GetAttestorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -491,7 +532,7 @@ class BinauthzManagementServiceV1AsyncClient:
         not exist.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.GetAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.GetAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.GetAttestor][].
             name (:class:`str`):
@@ -564,10 +605,10 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def update_attestor(
         self,
-        request: service.UpdateAttestorRequest = None,
+        request: Union[service.UpdateAttestorRequest, dict] = None,
         *,
         attestor: resources.Attestor = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -578,7 +619,7 @@ class BinauthzManagementServiceV1AsyncClient:
         not exist.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.UpdateAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.UpdateAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdateAttestor][].
             attestor (:class:`google.cloud.binaryauthorization_v1.types.Attestor`):
@@ -656,10 +697,10 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def list_attestors(
         self,
-        request: service.ListAttestorsRequest = None,
+        request: Union[service.ListAttestorsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsAsyncPager:
@@ -667,7 +708,7 @@ class BinauthzManagementServiceV1AsyncClient:
         Returns INVALID_ARGUMENT if the project does not exist.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.ListAttestorsRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.ListAttestorsRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.ListAttestors][].
             parent (:class:`str`):
@@ -749,10 +790,10 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def delete_attestor(
         self,
-        request: service.DeleteAttestorRequest = None,
+        request: Union[service.DeleteAttestorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -763,7 +804,7 @@ class BinauthzManagementServiceV1AsyncClient:
         not exist.
 
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1.types.DeleteAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1.types.DeleteAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.DeleteAttestor][].
             name (:class:`str`):
